@@ -86,7 +86,7 @@
 #define KAUTHCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KAUTHCORE_NO_DEPRECATED
-#  define KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54d00
+#  define KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KAUTHCORE_NO_DEPRECATED_WARNINGS
 #  define KAUTHCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE 0x54d00
+#    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -118,5 +118,12 @@
 #define KAUTHCORE_DEPRECATED_VERSION_5(minor, text)      KAUTHCORE_DEPRECATED_VERSION_5_##minor(text)
 #define KAUTHCORE_DEPRECATED_VERSION(major, minor, text) KAUTHCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KAUTHCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KAUTHCORE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KAUTHCORE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KAUTHCORE_DEPRECATED_VERSION(major, minor, text)
+#  define KAUTHCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KAUTHCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KAUTHCORE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KAUTHCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KAUTHCORE_EXPORT_H */
